This directory contains a Gradle plugin for build-time functionality,
such as generating specific metrics and documentation.

See `docs/user/adding-glean-to-your-project/index.md` for information about using this
plugin.
